==> jc-1.4.0.tar.gz: soot/jimple/toolkits/pointer/util/NativeMethodDriver.h <==
// public class soot.jimple.toolkits.pointer.util.NativeMethodDriver

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 31d83c08374f3ae soot_jimple_toolkits_pointer_util_NativeMethodDriver

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_pointer_util_NativeMethodDriver_H_
#define _JC_soot_jimple_toolkits_pointer_util_NativeMethodDriver_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_HashMap$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_jimple_toolkits_pointer_representations_ReferenceVariable$object;
struct _jc_soot_jimple_toolkits_pointer_util_NativeMethodDriver$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_pointer_util_NativeMethodDriver$sub_refs	_jc_soot_jimple_toolkits_pointer_util_NativeMethodDriver$sub_refs;
typedef struct _jc_soot_jimple_toolkits_pointer_util_NativeMethodDriver$sub_nonrefs	_jc_soot_jimple_toolkits_pointer_util_NativeMethodDriver$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_util_NativeMethodDriver$refs	_jc_soot_jimple_toolkits_pointer_util_NativeMethodDriver$refs;
typedef struct _jc_soot_jimple_toolkits_pointer_util_NativeMethodDriver$nonrefs	_jc_soot_jimple_toolkits_pointer_util_NativeMethodDriver$nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_util_NativeMethodDriver$object	_jc_soot_jimple_toolkits_pointer_util_NativeMethodDriver$object;

typedef const struct _jc_soot_jimple_toolkits_pointer_util_NativeMethodDriver$vmethods	_jc_soot_jimple_toolkits_pointer_util_NativeMethodDriver$vmethods;
typedef const struct _jc_soot_jimple_toolkits_pointer_util_NativeMethodDriver$vtable	_jc_soot_jimple_toolkits_pointer_util_NativeMethodDriver$vtable;
typedef const struct _jc_soot_jimple_toolkits_pointer_util_NativeMethodDriver$vtype	_jc_soot_jimple_toolkits_pointer_util_NativeMethodDriver$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_pointer_util_NativeMethodDriver$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_util_NativeMethodDriver$object *, struct _jc_soot_Singletons__24Global$object *);

// Virtual methods
extern jboolean _jc_soot_jimple_toolkits_pointer_util_NativeMethodDriver$method$process$47ab4fea4bf28160(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_util_NativeMethodDriver$object *, struct _jc_soot_SootMethod$object *, struct _jc_object *, struct _jc_object *, struct _jc_object_array *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_pointer_util_NativeMethodDriver$method_info$process$47ab4fea4bf28160;

// Static methods
extern struct _jc_soot_jimple_toolkits_pointer_util_NativeMethodDriver$object *_jc_soot_jimple_toolkits_pointer_util_NativeMethodDriver$method$v$534d05ddb83da216(_jc_env *);

// Virtual methods structure
struct _jc_soot_jimple_toolkits_pointer_util_NativeMethodDriver$vmethods {
	jboolean	(*process$47ab4fea4bf28160)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_util_NativeMethodDriver$object *, struct _jc_soot_SootMethod$object *, struct _jc_object *, struct _jc_object *, struct _jc_object_array *);
};

// Vtable
struct _jc_soot_jimple_toolkits_pointer_util_NativeMethodDriver$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_pointer_util_NativeMethodDriver$vmethods	soot_jimple_toolkits_pointer_util_NativeMethodDriver;
};

// Vtype
struct _jc_soot_jimple_toolkits_pointer_util_NativeMethodDriver$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_pointer_util_NativeMethodDriver$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_util_NativeMethodDriver$sub_refs {
	struct _jc_java_util_HashMap$object	*cnameToSim;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_util_NativeMethodDriver$refs {
    _jc_soot_jimple_toolkits_pointer_util_NativeMethodDriver$sub_refs	soot_jimple_toolkits_pointer_util_NativeMethodDriver;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_util_NativeMethodDriver$sub_nonrefs {
	jboolean	DEBUG;
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_util_NativeMethodDriver$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_pointer_util_NativeMethodDriver$sub_nonrefs	soot_jimple_toolkits_pointer_util_NativeMethodDriver;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_pointer_util_NativeMethodDriver$object {
	_jc_soot_jimple_toolkits_pointer_util_NativeMethodDriver$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_pointer_util_NativeMethodDriver$vtype	*vtype;
	_jc_soot_jimple_toolkits_pointer_util_NativeMethodDriver$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_pointer_util_NativeMethodDriver$vtype _jc_soot_jimple_toolkits_pointer_util_NativeMethodDriver$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_pointer_util_NativeMethodDriver, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_pointer_util_NativeMethodDriver$class_object;

#endif	/* _JC_soot_jimple_toolkits_pointer_util_NativeMethodDriver_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/toolkits/pointer/util/NativeMethodDriver.h <==
// public class soot.jimple.toolkits.pointer.util.NativeMethodDriver

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 31d83c08374f3ae soot_jimple_toolkits_pointer_util_NativeMethodDriver

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_pointer_util_NativeMethodDriver_H_
#define _JC_soot_jimple_toolkits_pointer_util_NativeMethodDriver_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_HashMap$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_jimple_toolkits_pointer_representations_ReferenceVariable$object;
struct _jc_soot_jimple_toolkits_pointer_util_NativeMethodDriver$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_pointer_util_NativeMethodDriver$sub_refs	_jc_soot_jimple_toolkits_pointer_util_NativeMethodDriver$sub_refs;
typedef struct _jc_soot_jimple_toolkits_pointer_util_NativeMethodDriver$sub_nonrefs	_jc_soot_jimple_toolkits_pointer_util_NativeMethodDriver$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_util_NativeMethodDriver$refs	_jc_soot_jimple_toolkits_pointer_util_NativeMethodDriver$refs;
typedef struct _jc_soot_jimple_toolkits_pointer_util_NativeMethodDriver$nonrefs	_jc_soot_jimple_toolkits_pointer_util_NativeMethodDriver$nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_util_NativeMethodDriver$object	_jc_soot_jimple_toolkits_pointer_util_NativeMethodDriver$object;

typedef const struct _jc_soot_jimple_toolkits_pointer_util_NativeMethodDriver$vmethods	_jc_soot_jimple_toolkits_pointer_util_NativeMethodDriver$vmethods;
typedef const struct _jc_soot_jimple_toolkits_pointer_util_NativeMethodDriver$vtable	_jc_soot_jimple_toolkits_pointer_util_NativeMethodDriver$vtable;
typedef const struct _jc_soot_jimple_toolkits_pointer_util_NativeMethodDriver$vtype	_jc_soot_jimple_toolkits_pointer_util_NativeMethodDriver$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_pointer_util_NativeMethodDriver$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_util_NativeMethodDriver$object *, struct _jc_soot_Singletons__24Global$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_soot_jimple_toolkits_pointer_util_NativeMethodDriver$method$process$47ab4fea4bf28160(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_util_NativeMethodDriver$object *, struct _jc_soot_SootMethod$object *, struct _jc_object *, struct _jc_object *, struct _jc_object_array *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_pointer_util_NativeMethodDriver$method_info$process$47ab4fea4bf28160;

// Static methods
extern struct _jc_soot_jimple_toolkits_pointer_util_NativeMethodDriver$object *_jc_soot_jimple_toolkits_pointer_util_NativeMethodDriver$method$v$534d05ddb83da216(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_pointer_util_NativeMethodDriver$vmethods {
	jboolean	(*process$47ab4fea4bf28160)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_util_NativeMethodDriver$object *, struct _jc_soot_SootMethod$object *, struct _jc_object *, struct _jc_object *, struct _jc_object_array *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_toolkits_pointer_util_NativeMethodDriver$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_pointer_util_NativeMethodDriver$vmethods	soot_jimple_toolkits_pointer_util_NativeMethodDriver;
};

// Vtype
struct _jc_soot_jimple_toolkits_pointer_util_NativeMethodDriver$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_pointer_util_NativeMethodDriver$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_util_NativeMethodDriver$sub_refs {
	struct _jc_java_util_HashMap$object	*cnameToSim;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_util_NativeMethodDriver$refs {
    _jc_soot_jimple_toolkits_pointer_util_NativeMethodDriver$sub_refs	soot_jimple_toolkits_pointer_util_NativeMethodDriver;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_util_NativeMethodDriver$sub_nonrefs {
	jboolean	DEBUG;
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_util_NativeMethodDriver$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_pointer_util_NativeMethodDriver$sub_nonrefs	soot_jimple_toolkits_pointer_util_NativeMethodDriver;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_pointer_util_NativeMethodDriver$object {
	_jc_soot_jimple_toolkits_pointer_util_NativeMethodDriver$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_pointer_util_NativeMethodDriver$vtype	*vtype;
	_jc_soot_jimple_toolkits_pointer_util_NativeMethodDriver$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_pointer_util_NativeMethodDriver$vtype _jc_soot_jimple_toolkits_pointer_util_NativeMethodDriver$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_pointer_util_NativeMethodDriver, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_pointer_util_NativeMethodDriver$class_object;

#endif	/* _JC_soot_jimple_toolkits_pointer_util_NativeMethodDriver_H_ */
